## cdist-type__package_emerge_dependencies(7)

### Thomas Oettli

`<otho--@--sfs.biz>`

## 1. NAME

cdist-typepackage_emerge_dependencies - Install dependencies for package_emerge

## 2. DESCRIPTION

Portage is usually used on the gentoo distribution to manage packages. This type installs the following tools which are required by __package_emerge to work: app-portage/flaggie app-portage/gentoolkit

## 3. REQUIRED PARAMETERS

None

## 4. OPTIONAL PARAMETERS

None

## 5. EXAMPLES

    # Ensure app-portage/flaggie and app-portage/gentoolkit are installed
    __package_emerge_dependencies

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__package(7)
- cdist-type__package_emerge(7)

## 7. COPYING

Copyright (C) 2013 Thomas Oettli. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).